*************************************************************************************************
* Revealing Tax Evasion: Experimental Evidence from a Representative Survey of Indonesian Firms *
*************************************************************************************************
********************* Christopher Hoy, Filip Jolevski, Anthony Obeyesekere **********************
*************************************************************************************************
clear all
set more off

* Define Globals
global dir "C:\WBG\github\RR_IDN_2024_171\reppackage"
sysdir set PLUS "${dir}\Stata\ado"
set varabbrev on

net install grc1leg, from (http://www.stata.com/users/vwiggins)
ssc install estout, replace
ssc install ietoolkit, replace
********************
** Part A: SET-UP **
********************
use "$dir\Stata\Data\Indonesia-2023-full-data.dta"



** Create Directories **
!rmdir "$dir\Stata\Tables and Figures" /Q
!mkdir "$dir\Stata\Tables and Figures"


* Remove refusals to respond to these questions
foreach var in IDa1 IDa2 {
	replace `var' = . if `var' < 0
}

*** Generate a variable indicating a refusal
gen refusal = 1
replace refusal = 0 if IDa1!=. & IDa2!=.

*** Generate Joined Experiment variables
gen control = IDa1 if rotation == 1
replace control = IDa2 if rotation == 2

gen treatment = IDa1 if rotation == 2
replace treatment = IDa2 if rotation == 1

*** Generate the sum of the two responses
gen item_total = IDa1 + IDa2

*** Generate Dummy Variables that indicate treatment and control for each list
gen treat1 = .
replace treat1 = 1 if rotation == 2
replace treat1 = 0 if rotation == 1

gen treat2 = .
replace treat2 = 1 if rotation == 1
replace treat2 = 0 if rotation == 2




***************************
** Part B: MAIN ANALYSIS **
***************************

** Figure 1: Distribution of Responses **
gen IDa1_treat = IDa1 if treat1==1
gen IDa1_control = IDa1 if treat1==0

gen IDa2_treat = IDa2 if treat2==1
gen IDa2_control = IDa2 if treat2==0

twoway (histogram IDa1_treat, discrete percent fcolor(red%40)) (histogram IDa1_control, discrete percent fcolor(green%35)), legend(label(1 "Treatment") label(2 "Control") col(2) pos(6)) title("List 1") saving(IDa1, replace)

twoway (histogram IDa2_treat, discrete percent fcolor(red%40)) (histogram IDa2_control, discrete percent fcolor(green%35)), legend(off) ytitle("") title("List 2") saving(IDa2, replace)

grc1leg IDa1.gph IDa2.gph, ycommon

graph export "$dir\Stata\Tables and Figures\\${output}Figure1.png", replace
 


** Table 2: Main Analysis **
ttest IDa1, by(treat2)
matrix c1 = [r(mu_2), r(mu_1), r(mu_1) - r(mu_2), r(se), r(N_1) + r(N_2)]

ttest IDa2, by(treat1)
matrix c2 = [r(mu_2), r(mu_1), r(mu_1) - r(mu_2), r(se), r(N_1) + r(N_2)]

ttest treatment==control, unpair 
matrix c3 = [r(mu_2), r(mu_1), r(mu_1) - r(mu_2), r(se), r(N_1) + r(N_2)]

mat c = [c1\c2\c3]
mat rownames c = "List 1" "List 2" "List 1+2"
mat colnames c = "Control" "Treatment" "Difference" "SE" "N"
esttab matrix(c) using "$dir\Stata\Tables and Figures\\Table2.tex", wide replace title("Table 2: Main Results") nomti



** Table A2: Main Analysis (weighted and balanced sample) **
reg IDa1 treat1 [pw=wmedian] if refusal == 0, cluster(strata)
matrix d1 = [_b[_cons],_b[_cons] + _b[treat1], _b[treat1], _se[treat1], e(N)]

reg IDa2 treat2 [pw=wmedian]if refusal == 0, cluster(strata)
matrix d2 = [_b[_cons],_b[_cons] + _b[treat2], _b[treat2], _se[treat2], e(N)]

mean control treatment [pw=wmedian] if refusal == 0, cluster(strata)
matrix d31 = [_b[control], _b[treatment], _b[treatment] - _b[control]]
lincom treatment - control
matrix d32 =  [r(se), e(N)]
matrix d3 = [d31,d32]

mat d = [d1\d2\d3]
mat rownames d = "List 1" "List 2" "List 1+2"
mat colnames d = "Control" "Treatment" "Difference" "SE" "N"
esttab matrix(d) using "$dir\Stata\Tables and Figures\\TableA2.tex", wide replace title("Table A2: Main Results (weighted using a paired test)") nomti



 
*********************************************
** Part C: HETEROGENIOUS EFFECTS & BALANCE **
*********************************************

***Hetereogenous treatment effects***
**Define background variables**
gen soleproprietor = 0
replace soleproprietor = 1 if b1==3

gen local_sales = 0
replace local_sales = 1 if e1==1

gen small = 0
replace small = 1 if a6b==1

gen medium = 0
replace medium = 1 if a6b==2

gen large = 0
replace large = 1 if a6b==3

gen lessthan10yrs = 0
replace lessthan10yrs = 1 if b5>2012

gen reg_lessthan10yrs = 0
replace reg_lessthan10yrs = 1 if b6b>2012

gen man_lessthan10yrs = 0
replace man_lessthan10yrs = 1 if b7<10

gen manufactoring = 0
replace manufactoring = 1 if d1a1a==1

gen retail_whole = 0
replace retail_whole = 1 if d1a1a==2
replace retail_whole = 1 if d1a1a==3

gen sales_under100mil = 0
replace sales_under100mil = 1 if d2<100000000 & d2!=.

gen sales_100_800mil = 0
replace sales_100_800mil = 1 if d2>100000000 & d2<800000000 

gen sales_100_500mil = 0
replace sales_100_500mil = 1 if d2>100000000 & d2<500000000 

gen sales_over800mil = 0
replace sales_over800mil = 1 if d2>800000000 & d2!=.

gen sales_over500mil = 0
replace sales_over500mil = 1 if d2>500000000 & d2!=.

gen sales_over300mil = 0
replace sales_over300mil = 1 if d2>300000000 & d2!=.

gen sales_over100mil = 0
replace sales_over100mil = 1 if d2>100000000 & d2!=.

gen sales_over1000mil = 0
replace sales_over1000mil = 1 if d2>1000000000 & d2!=.

gen services = 0
replace services = 1 if a4a==14
replace services = 1 if a4a==15
replace services = 1 if a4a==16
replace services = 1 if a4a==17
replace services = 1 if a4a==18
replace services = 1 if a4a==19

gen informal_comp = 0
replace informal_comp = 1 if e11==1

gen auditor = 0
replace auditor = 1 if k21==1

gen informal_obst = 0
replace informal_obst = 1 if e30==2
replace informal_obst = 1 if e30==3
replace informal_obst = 1 if e30==4

gen bank_account = 0
replace bank_account = 1 if k6==1

gen inspected = 0
replace inspected = 1 if j3==1

gen CIT = 0
replace CIT = 1 if t1a==1

gen VAT = 0
replace VAT = 1 if t1c==1

gen gov_contract = 0
replace gov_contract = 1 if j6a==1

gen taxrates_obst = 0
replace taxrates_obst = 1 if j30a==2
replace taxrates_obst = 1 if j30a==3
replace taxrates_obst = 1 if j30a==4

gen taxadmin_obst = 0
replace taxadmin_obst = 1 if j30b==2
replace taxadmin_obst = 1 if j30b==3
replace taxadmin_obst = 1 if j30b==4

gen java = 0
replace java = 1 if a2==1
replace java = 1 if a2==2
replace java = 1 if a2==3
replace java = 1 if a2==4
replace java = 1 if a2==5
replace java = 1 if a2==6

gen owner_manager = 0
replace owner_manager = 1 if b3a==1

gen female_manager = 0
replace female_manager = 1 if b7a==1

gen foreign = 0
replace foreign = 1 if b2b>0

gen national_sales = 0
replace national_sales = 1 if d3a==100

gen formal_bank = 0
replace formal_bank = 1 if k6==1
replace formal_bank = 1 if k7==1
replace formal_bank = 1 if k8==1
replace formal_bank = 1 if k8==2
replace formal_bank = 1 if k8==3

gen loan = 0
replace loan = 1 if k82==1
replace loan = 1 if k82==2
replace loan = 1 if k82==3

gen DGT_fair = 0
replace DGT_fair = 1 if IDj1==3
replace DGT_fair = 1 if IDj1==4

gen informal_payments = 0
replace informal_payments = 1 if j7a>0

gen easy_avoid = 0
replace easy_avoid = 1 if t4a==1
replace easy_avoid = 1 if t4a==2
replace easy_avoid = 1 if t4b==1
replace easy_avoid = 1 if t4b==2

gen wrong_pun = 0
replace wrong_pun = 1 if t6==3

gen should_pay = 0
replace should_pay = 1 if t7==1

gen tax_admin = (taxadmin_obst ==1) 
gen not_tax_admin = (taxadmin_obst ==0) 

gen exporter = (national_sales ==0) 
gen not_exporter = (national_sales ==1) 

gen informal_com = (informal_comp ==1) 
gen not_informal_com = (informal_com ==0) 

gen not_loan = (loan ==0) 


** Table A1: Balancing Test **
iebaltab soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected CIT VAT gov_contract large, grpv(rotation) savetex("$dir\Stata\Tables and Figures\\TableA1") ft replace



*** Hetereogenous Effects Set-up**
**Tax admin obstacles**
gen tax_admin_treat1 = tax_admin*treat1
gen not_tax_admin_treat1 = not_tax_admin*treat1

gen tax_admin_treat2 = tax_admin*treat2
gen not_tax_admin_treat2 = not_tax_admin*treat2


**Non-exporter**
gen exporter_treat1 = exporter*treat1
gen not_exporter_treat1 = not_exporter*treat1

gen exporter_treat2 = exporter*treat2
gen not_exporter_treat2 = not_exporter*treat2


**Informal sector**
gen informal_com_treat1 = informal_com*treat1
gen not_informal_com_treat1 = not_informal_com*treat1

gen informal_com_treat2 = informal_com*treat2
gen not_informal_com_treat2 = not_informal_com*treat2


**Loan**
gen loan_treat1 = loan*treat1
gen not_loan_treat1 = not_loan*treat1

gen loan_treat2 = loan*treat2
gen not_loan_treat2 = not_loan*treat2


** Table 3: Hetereogenous Effects **
* Sole Proprietorship
reg IDa1 treat1 
matrix e1a = [_b[treat1]\_se[treat1]]
matrix e18a = [e(N)]

reg IDa1 treat1 soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e1b = [_b[treat1]\_se[treat1]]
matrix e18b = [e(N)]

reg IDa2 treat2 
matrix e1c = [_b[treat2]\_se[treat2]]
matrix e18c = [e(N)]

reg IDa2 treat2 soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e1d = [_b[treat2]\_se[treat2]]
matrix e18d = [e(N)]

matrix e1 = [e1a,e1b,e1c,e1d]
matrix e18 = [e18a,e18b,e18c,e18d]



* Exporter *
reg IDa1 exporter_treat1 not_exporter_treat1 exporter 
matrix e3a = [_b[exporter_treat1]\_se[exporter_treat1]\_b[not_exporter_treat1]\_se[not_exporter_treat1]]

test exporter_treat1 = not_exporter_treat1
matrix e7a = [r(p)]


reg IDa1 exporter_treat1 not_exporter_treat1 exporter soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e3b = [_b[exporter_treat1]\_se[exporter_treat1]\_b[not_exporter_treat1]\_se[not_exporter_treat1]]

test exporter_treat1 = not_exporter_treat1
matrix e7b = [r(p)]


reg IDa2 exporter_treat2 not_exporter_treat2 exporter 
matrix e3c = [_b[exporter_treat2]\_se[exporter_treat2]\_b[not_exporter_treat2]\_se[not_exporter_treat2]]

test exporter_treat2 = not_exporter_treat2
matrix e7c = [r(p)]


reg IDa2 exporter_treat2 not_exporter_treat2 exporter soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e3d = [_b[exporter_treat2]\_se[exporter_treat2]\_b[not_exporter_treat2]\_se[not_exporter_treat2]]

test exporter_treat2 = not_exporter_treat2
matrix e7d = [r(p)]

matrix e3 = [e3a,e3b,e3c,e3d]
matrix e7 = [e7a,e7b,e7c,e7d]



* Tax administration *
reg IDa1 tax_admin_treat1 not_tax_admin_treat1 tax_admin 
matrix e8a = [_b[tax_admin_treat1]\_se[tax_admin_treat1]\_b[not_tax_admin_treat1]\_se[not_tax_admin_treat1]]

test tax_admin_treat1 = not_tax_admin_treat1
matrix e12a = [r(p)]


reg IDa1 tax_admin_treat1 not_tax_admin_treat1 tax_admin soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e8b = [_b[tax_admin_treat1]\_se[tax_admin_treat1]\_b[not_tax_admin_treat1]\_se[not_tax_admin_treat1]]

test tax_admin_treat1 = not_tax_admin_treat1
matrix e12b = [r(p)]


reg IDa2 tax_admin_treat2 not_tax_admin_treat2 tax_admin 
matrix e8c = [_b[tax_admin_treat2]\_se[tax_admin_treat2]\_b[not_tax_admin_treat2]\_se[not_tax_admin_treat2]]

test tax_admin_treat2 = not_tax_admin_treat2
matrix e12c = [r(p)]


reg IDa2 tax_admin_treat2 not_tax_admin_treat2 tax_admin soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e8d = [_b[tax_admin_treat2]\_se[tax_admin_treat2]\_b[not_tax_admin_treat2]\_se[not_tax_admin_treat2]]

test tax_admin_treat2 = not_tax_admin_treat2
matrix e12d = [r(p)]

matrix e8 = [e8a,e8b,e8c,e8d]
matrix e12 = [e12a,e12b,e12c,e12d]



* Informal competition *
reg IDa1 informal_com_treat1 not_informal_com_treat1 informal_com 
matrix e13a = [_b[informal_com_treat1]\_se[informal_com_treat1]\_b[not_informal_com_treat1]\_se[not_informal_com_treat1]]

test informal_com_treat1 = not_informal_com_treat1
matrix e17a = [r(p)]


reg IDa1 informal_com_treat1 not_informal_com_treat1 informal_com soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e13b = [_b[informal_com_treat1]\_se[informal_com_treat1]\_b[not_informal_com_treat1]\_se[not_informal_com_treat1]]

test informal_com_treat1 = not_informal_com_treat1
matrix e17b = [r(p)]


reg IDa2 informal_com_treat2 not_informal_com_treat2 informal_com 
matrix e13c = [_b[informal_com_treat2]\_se[informal_com_treat2]\_b[not_informal_com_treat2]\_se[not_informal_com_treat2]]

test informal_com_treat2 = not_informal_com_treat2
matrix e17c = [r(p)]


reg IDa2 informal_com_treat2 not_informal_com_treat2 informal_com soleproprietor lessthan10yrs manufactoring informal_comp retail_whole services local_sales informal_obst bank_account auditor inspected gov_contract large
matrix e13d = [_b[informal_com_treat2]\_se[informal_com_treat2]\_b[not_informal_com_treat2]\_se[not_informal_com_treat2]]

test informal_com_treat2 = not_informal_com_treat2
matrix e17d = [r(p)]

matrix e13 = [e13a,e13b,e13c,e13d]
matrix e17 = [e17a,e17b,e17c,e17d]

matrix e = [e1\e3\e7\e8\e12\e13\e17\e18]
mat rownames e = "Tax Evasion Rate (Full Sample)" "" "Tax Evasion Rate (Exporters)" "" "Tax Evasion Rate (Non-exporters)" "" "p-value difference" "Tax Evasion Rate (Tax Admin: obstacle)" "" "Tax Evasion Rate (Tax Admin: NOT obstacle)" "" "p-value difference" "Tax Evasion Rate (Informal comp)" "" "Tax Evasion Rate (No inf comp)" "" "p-value difference" "Sample Size"
mat colnames e = "(1)" "(2)" "(3)" "(4)"

esttab matrix(e) using "$dir\Stata\Tables and Figures\\Table3.tex", replace wide title("Table 3: Heterogeneity of tax evasion by firm characteristics") nomti

save "$dir\Rcode\data\data_set.dta", replace
